==> libcsfml_2.6.0.orig.tar.xz: libcsfml-2.6.0/src/SFML/Window/Vulkan.cpp <==
////////////////////////////////////////////////////////////
//
// SFML - Simple and Fast Multimedia Library
// Copyright (C) 2007-2023 Laurent Gomila (laurent@sfml-dev.org)
//
// This software is provided 'as-is', without any express or implied warranty.
// In no event will the authors be held liable for any damages arising from the use of this software.
//
// Permission is granted to anyone to use this software for any purpose,
// including commercial applications, and to alter it and redistribute it freely,
// subject to the following restrictions:
//
// 1. The origin of this software must not be misrepresented;
//    you must not claim that you wrote the original software.
//    If you use this software in a product, an acknowledgment
//    in the product documentation would be appreciated but is not required.
//
// 2. Altered source versions must be plainly marked as such,
//    and must not be misrepresented as being the original software.
//
// 3. This notice may not be removed or altered from any source distribution.
//
////////////////////////////////////////////////////////////

////////////////////////////////////////////////////////////
// Headers
////////////////////////////////////////////////////////////
#include <SFML/Window/Export.h>
#include <SFML/Window/Vulkan.h>
#include <SFML/Window/Vulkan.hpp>

#include <stdlib.h>
#include <string.h>


////////////////////////////////////////////////////////////
sfBool sfVulkan_isAvailable(sfBool requireGraphics)
{
    return sf::Vulkan::isAvailable(requireGraphics);
}


////////////////////////////////////////////////////////////
sfVulkanFunctionPointer sfVulkan_getFunction(const char* name)
{
    return sf::Vulkan::getFunction(name);
}


////////////////////////////////////////////////////////////
const char* const* sfVulkan_getGraphicsRequiredInstanceExtensions()
{
    return &sf::Vulkan::getGraphicsRequiredInstanceExtensions()[0];
}

==> libcsfml_2.6.1.orig.tar.xz: libcsfml-2.6.1/src/SFML/Window/Vulkan.cpp <==
////////////////////////////////////////////////////////////
//
// SFML - Simple and Fast Multimedia Library
// Copyright (C) 2007-2024 Laurent Gomila (laurent@sfml-dev.org)
//
// This software is provided 'as-is', without any express or implied warranty.
// In no event will the authors be held liable for any damages arising from the use of this software.
//
// Permission is granted to anyone to use this software for any purpose,
// including commercial applications, and to alter it and redistribute it freely,
// subject to the following restrictions:
//
// 1. The origin of this software must not be misrepresented;
//    you must not claim that you wrote the original software.
//    If you use this software in a product, an acknowledgment
//    in the product documentation would be appreciated but is not required.
//
// 2. Altered source versions must be plainly marked as such,
//    and must not be misrepresented as being the original software.
//
// 3. This notice may not be removed or altered from any source distribution.
//
////////////////////////////////////////////////////////////

////////////////////////////////////////////////////////////
// Headers
////////////////////////////////////////////////////////////
#include <SFML/Window/Export.h>
#include <SFML/Window/Vulkan.h>
#include <SFML/Window/Vulkan.hpp>

#include <stdlib.h>
#include <string.h>


////////////////////////////////////////////////////////////
sfBool sfVulkan_isAvailable(sfBool requireGraphics)
{
    return sf::Vulkan::isAvailable(requireGraphics);
}


////////////////////////////////////////////////////////////
sfVulkanFunctionPointer sfVulkan_getFunction(const char* name)
{
    return sf::Vulkan::getFunction(name);
}


////////////////////////////////////////////////////////////
const char* const* sfVulkan_getGraphicsRequiredInstanceExtensions(size_t* count)
{
    static std::vector<const char*> extensions = sf::Vulkan::getGraphicsRequiredInstanceExtensions();

    if (count)
        *count = extensions.size();

    return !extensions.empty() ? &extensions[0] : NULL;
}
